Reading and writing
===================

Module tock.tables
------------------

.. automodule:: tock.tables
   :members:

Module tock.graphs
------------------

.. automodule:: tock.graphs
   :members:

